#
# spec file for package Modules
#
# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           Modules
BuildRequires:  automake
BuildRequires:  tcl-devel
# xorg-x11-devel
Url:            http://modules.sourceforge.net/
Version:        3.2.10
Release:        11.5
Summary:        Environment Modules
License:        BSD-3-Clause and GPL-2.0+ and LGPL-2.1+
Group:          System/Management
Requires:       tcl
Source:         modules-%{version}.tar.bz2
# PATCH-FIX-OPENSUSE share.patch
Patch0:         share.patch
# PATCH-FIX-UPSTREAM return.patch 
Patch1:         return.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Provides:       environment-modules
Obsoletes:      environment-modules < %{version}

%description
The Modules package provides for dynamic modification of a user's
environment with module files.	Each module file contains the
information needed to configure the shell for an application. Once the
package is initialized, the environment can be modified dynamically on
a per-module basis using the module command that interprets module
files. Typically, module files instruct the module command to alter or
set shell environment variables, such as PATH or MANPATH. Module files
may be shared by many users on a system and users may have their own
collection to supplement or replace the shared module files.  The
modules environment is common on SGI/Crays and many workstation farms.



Authors:
--------
    John L. Furlan <jlf@behere.com>
    Peter W. Osel <pwo@Osel.DE>
    Jens  Hamisch <Jens.Hamisch@Strawberry.COM>
    R.K. Owen <rk@owen.sj.ca.us>

%prep
%setup -q -n modules-%{version}
%patch0 -p1
%patch1 -p1

%build
aclocal --force -I config
autoreconf --force --install
CFLAGS="$RPM_OPT_FLAGS -fno-strict-aliasing -DUSE_INTERP_RESULT -DUSE_INTERP_ERRORLINE" \
./configure \
                --prefix=/usr \
                --with-version-path=/usr/share/modules \
                --with-module-path=/usr/share/modules/modulefiles \
		--mandir=%{_mandir} \
                --with-etc-path=/etc \
                --with-skel-path=/etc/skel \
		--with-tcl=%{_libdir} \
		--without-x
make

%install
install -d $RPM_BUILD_ROOT/usr/share/modules
install -d $RPM_BUILD_ROOT/etc/profile.d
install -m 644 etc/global/profile.modules $RPM_BUILD_ROOT/etc/profile.d/modules.sh
install -m 644 etc/global/csh.modules $RPM_BUILD_ROOT/etc/profile.d/modules.csh
sed -i "s;/default/;/%{version}/;g" $RPM_BUILD_ROOT/etc/profile.d/modules.sh
sed -i "s;/default/;/%{version}/;g" $RPM_BUILD_ROOT/etc/profile.d/modules.csh

make DESTDIR=$RPM_BUILD_ROOT install
install -d $RPM_BUILD_ROOT/usr/bin
pushd $RPM_BUILD_ROOT/usr/bin
ln -s ../share/Modules/%{version}/bin/add.modules .
ln -s ../share/Modules/%{version}/bin/mkroot .
ln -s ../share/Modules/%{version}/bin/modulecmd .
popd

%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(-,root,root)
%doc ChangeLog LICENSE.GPL NEWS README TODO
%dir %{_prefix}/share/Modules
%{_prefix}/share/Modules/*
%dir /usr/share/modules
/usr/share/modules/*
%{_bindir}/*
%config /etc/profile.d/modules.*
%doc %{_mandir}/man4/*
%doc %{_mandir}/man1/*

%changelog
* Thu Aug  1 2013 max@suse.com
- Set -DUSE_INTERP_RESULT and -DUSE_INTERP_ERRORLINE" to fix build
  with Tcl 8.6.
* Mon Feb  4 2013 coolo@suse.com
- update license to new format
* Fri Dec 21 2012 kkaempf@suse.com
- update to 3.2.10
  * Fixed the module switch with custom delimiters (Tyson Whitehead)
  * If a bash shell check if interactive or not for alias/functions
  * Fix the flags with regards to recursive load/unload
  * Fix perl.pm init file typo (bug 3497092)
  * Moved from cvs to git (and now: modulefile/module-git)
  * Fix the module swap with the --delim option (Tyson Whitehead)
  * Increased the "update" buffer (Leon Kos)
  * Use the locale for sorting modulefiles by the avail command
  * Fixed the segfault problem with Tcl_RegExpCompile() (Kenneth Hoste,
    Tyson Whitehead)
  * Updated the FSF address in LICENSE.GPL (Jan Synacek)
  * Forked the Tcl-only version to be maintained by Kent Mein.
  * Added the "module-info type" query to return 'C' to indicate that
    the modulecmd executable is the "C" version.
    (The Tcl-only version will return 'Tcl'.)
  * Search /usr/lib64 for tclConfig.sh also (Jan Synacek)
  * Tested loading 20 other modulefiles from a single one
  * Have ChangeLog generated by a script due to Marcus D. Hanwell
* Mon Sep 10 2012 kkaempf@suse.com
- complete the move from /usr/Modules to /usr/share/Modules
  (bnc#778525)
* Wed Aug 29 2012 alinm.elena@gmail.com
- update to 3.2.9c
  * Fix the coexistence of load/remove flags (Martin Siegert)
  * Fixed an overlapping string copy (Wilson Snyder & Orion Poplawski)
  * Isolated calls to the new interpreter and get & set env.vars.
  * Crucial bug fix of same by (Orion Poplawski).
  * Optionally use Tcl memory check routines for malloc/realloc.
  * Fixed the "module purge" memory corruption (Poor Yorick)
  * Added support for Ruby (Tammo Tjarks)
- replace defaut in the profile files with the proper version
- make module files from /etc %%config
* Thu Dec  1 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Tue Oct 18 2011 kkaempf@suse.com
- move /usr/Modules to /usr/share/Modules for FHS 2.2
* Tue Oct 18 2011 kkaempf@suse.com
- update to 3.2.8a
  * switched to 3.2 release
  * lots of changes and bugfixes
  * see NEWS for details
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Jan 20 2006 mrueckert@suse.de
- Remove temporary files if they are no longer used.
  (#73973,#144398)
* Tue Jan 17 2006 mrueckert@suse.de
- fix version path so modules find its configs again
* Mon Sep 13 2004 nashif@suse.de
- Fixed trap call in profile.d script (#45056)
* Thu Sep  2 2004 nashif@suse.de
- #43781: Fixed segfault, verify tmp file was created.
* Sat Aug 14 2004 nashif@suse.de
- Renamed package
- Fixed mkstemp (#43781)
* Sat Apr 24 2004 nashif@suse.de
- Added -fno-strict-aliasing to CFLAGS
* Sat Jan 10 2004 adrian@suse.de
- use x-devel-packages
* Sat May 17 2003 nashif@suse.de
- Fixed file list in spec file
* Tue Aug  6 2002 nashif@suse.de
- fixed sourcing of global configuration file
* Mon Feb 11 2002 nashif@suse.de
- new version: 3.1.6
* Wed Jun  6 2001 nashif@suse.de
- Fixed configure.in
* Mon Feb 19 2001 nashif@suse.de
- Initial Release (Version 3.1.1)
